/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.readers.its;

// BRIDGE API
import com.rempl.readers.its.bridge.Bridge;
import com.rempl.readers.its.bridge.BridgeException;
import com.rempl.readers.its.bridge.Issue;

// for manipulations with issues
import java.util.Map;

/**
 * Non-implemented Bridge, as a stub.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: DummyBridge.java 983 2011-03-29 12:36:17Z yegor256@yahoo.com $
 */
public final class DummyBridge implements Bridge {

    /**
     * The message.
     */
    private String message;

    /**
     * {@inheritDoc}
     */
    @Override
    public void configure(final Map<String, String> params)
        throws BridgeException {
        this.message = params.get("message")
            .replaceAll("\\s+", " ")
            .trim();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Map<String, Issue> retrieve() throws BridgeException {
        throw new BridgeException(this.message);
    }

}
